@@ -5,8 +5,8 @@
 /* { dg-error "unterminated comment" "" { target *-*-* } 4 } */
 /* { dg-error "unterminated comment" "header error" { target *-*-* } 8 } */
 
-#include "19940712-1.h"	  /* { dg-error "" }  // In file included from: */
-#include "19940712-1a.h"  /* { dg-error "" }  // In file included from: */
+#include "19940712-1.h"	  /* { dg-message "" }  // In file included from: */
+#include "19940712-1a.h"  /* { dg-message "" }  // In file included from: */
 #include "19940712-1b.h"
 
 /* comment start in comment error
