@@ -3,10 +3,10 @@
 
 /* Test that the intrinsics compile without optimization.  All of them are
    defined as inline functions in mmintrin.h that reference the proper
-   builtin functions.  Defining away "static" and "__inline" results in
+   builtin functions.  Defining away "extern" and "__inline" results in
    all of them being compiled as proper functions.  */
 
-#define static
+#define extern
 #define __inline
 
 #include <mmintrin.h>
